@@ -22,7 +22,7 @@ class Terminal : public QObject
 
 public:
     explicit Terminal(const QString &workingDir, QWidget *parent = nullptr);
-    ~Terminal();
+    ~Terminal() override;
 
     bool eventFilter(QObject *watched, QEvent *event) override;
 
@@ -58,7 +58,7 @@ public:
     void manageProfiles();
     void editProfile();
 
-    bool keyboardInputEnabled()
+    bool keyboardInputEnabled() const
     {
         return m_keyboardInputEnabled;
     }
@@ -67,13 +67,13 @@ public:
         m_keyboardInputEnabled = enabled;
     }
 
-    bool monitorActivityEnabled()
+    bool monitorActivityEnabled() const
     {
         return m_monitorActivityEnabled;
     }
     void setMonitorActivityEnabled(bool enabled);
 
-    bool monitorSilenceEnabled()
+    bool monitorSilenceEnabled() const
     {
         return m_monitorSilenceEnabled;
     }
