@@ -53,9 +53,7 @@ TitleBar::TitleBar(MainWindow *mainWindow)
     connect(m_quitButton, SIGNAL(clicked()), mainWindow, SLOT(close()));
 }
 
-TitleBar::~TitleBar()
-{
-}
+TitleBar::~TitleBar() = default;
 
 void TitleBar::setVisible(bool visible)
 {
@@ -147,7 +145,7 @@ void TitleBar::mouseMoveEvent(QMouseEvent *event)
         MainWindow *window = dynamic_cast<MainWindow *>(parent());
 
         int maxHeight = window->getDesktopGeometry().height();
-        int newHeight = event->globalY() / (maxHeight / 100);
+        int newHeight = event->globalPosition().y() / (maxHeight / 100);
 
         // Correct newHeight if mouse is dragged too far
         if (newHeight > 100) {
@@ -189,7 +187,7 @@ void TitleBar::setFocusButtonState(bool checked)
     m_focusButton->setChecked(checked);
 }
 
-QString TitleBar::title()
+QString TitleBar::title() const
 {
     if (!m_skin->titleBarText().isEmpty() && !m_title.isEmpty())
         return m_title + QStringLiteral(" - ") + m_skin->titleBarText();
