@@ -25,9 +25,7 @@ EventRect::EventRect(const QPoint &topLeft, const QPoint &bottomRight, EventType
     m_timeStamp.start();
 }
 
-EventRect::~EventRect()
-{
-}
+EventRect::~EventRect() = default;
 
 bool EventRect::operator==(const EventRect &eventRect) const
 {
@@ -73,9 +71,7 @@ VisualEventOverlay::VisualEventOverlay(SessionStack *parent)
     hide();
 }
 
-VisualEventOverlay::~VisualEventOverlay()
-{
-}
+VisualEventOverlay::~VisualEventOverlay() = default;
 
 void VisualEventOverlay::highlightTerminal(Terminal *terminal, bool persistent)
 {
@@ -201,7 +197,7 @@ void VisualEventOverlay::hideEvent(QHideEvent *)
 
 void VisualEventOverlay::scheduleCleanup(int in)
 {
-    int left = (m_cleanupTimerStarted.isValid())? m_cleanupTimerCeiling - m_cleanupTimerStarted.elapsed() : 0;
+    int left = (m_cleanupTimerStarted.isValid()) ? m_cleanupTimerCeiling - m_cleanupTimerStarted.elapsed() : 0;
 
     if (in > left) {
         m_cleanupTimerCeiling = in;
